import { utils, BigNumberish, BytesLike, BigNumber, BaseContract, Signer, PayableOverrides, ContractTransaction, CallOverrides, Overrides, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result, EventFragment } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common';

interface IDropERC1155Interface extends utils.Interface {
    contractName: string | "IDropERC1155";
    functions: {
        "claim(address,uint256,uint256,bytes32[])": FunctionFragment;
        "contractType()": FunctionFragment;
        "contractURI()": FunctionFragment;
        "contractVersion()": FunctionFragment;
        "getPlatformFeeInfo()": FunctionFragment;
        "getRoyaltyInfo()": FunctionFragment;
        "getRoyaltyRecipientForToken(uint256)": FunctionFragment;
        "lazyMint(uint256,string)": FunctionFragment;
        "owner()": FunctionFragment;
        "primarySaleRecipient()": FunctionFragment;
        "royaltyInfo(uint256,uint256)": FunctionFragment;
        "setClaimConditions(uint256,(uint256,uint256,uint256,uint256,uint256,bytes32,uint256,address)[],bool)": FunctionFragment;
        "setContractURI(string)": FunctionFragment;
        "setOwner(address)": FunctionFragment;
        "setPlatformFeeInfo(address,uint256)": FunctionFragment;
        "setPrimarySaleRecipient(address)": FunctionFragment;
        "setRoyaltyInfo(address,uint256)": FunctionFragment;
        "setRoyaltyRecipientForToken(uint256,address)": FunctionFragment;
        "supportsInterface(bytes4)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "claim", values: [string, BigNumberish, BigNumberish, BytesLike[]]): string;
    encodeFunctionData(functionFragment: "contractType", values?: undefined): string;
    encodeFunctionData(functionFragment: "contractURI", values?: undefined): string;
    encodeFunctionData(functionFragment: "contractVersion", values?: undefined): string;
    encodeFunctionData(functionFragment: "getPlatformFeeInfo", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRoyaltyInfo", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRoyaltyRecipientForToken", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "lazyMint", values: [BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "primarySaleRecipient", values?: undefined): string;
    encodeFunctionData(functionFragment: "royaltyInfo", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setClaimConditions", values: [BigNumberish, IDropERC1155.ClaimConditionStruct[], boolean]): string;
    encodeFunctionData(functionFragment: "setContractURI", values: [string]): string;
    encodeFunctionData(functionFragment: "setOwner", values: [string]): string;
    encodeFunctionData(functionFragment: "setPlatformFeeInfo", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setPrimarySaleRecipient", values: [string]): string;
    encodeFunctionData(functionFragment: "setRoyaltyInfo", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setRoyaltyRecipientForToken", values: [BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "supportsInterface", values: [BytesLike]): string;
    decodeFunctionResult(functionFragment: "claim", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "contractType", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "contractURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "contractVersion", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPlatformFeeInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoyaltyInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoyaltyRecipientForToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "lazyMint", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "primarySaleRecipient", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "royaltyInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setClaimConditions", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setContractURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setOwner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPlatformFeeInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPrimarySaleRecipient", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRoyaltyInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRoyaltyRecipientForToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supportsInterface", data: BytesLike): Result;
    events: {
        "ClaimedTokens(uint256,uint256,address,address,uint256)": EventFragment;
        "EtherReceived(address,uint256)": EventFragment;
        "FundsWithdrawn(address,address,uint256,uint256)": EventFragment;
        "LazyMintedTokens(uint256,uint256,string)": EventFragment;
        "NewClaimConditions(uint256,tuple[])": EventFragment;
        "NewOwner(address,address)": EventFragment;
        "NewPrimarySaleRecipient(address)": EventFragment;
        "PlatformFeeUpdates(address,uint256)": EventFragment;
        "RoyaltyRecipient(uint256,address)": EventFragment;
        "RoyaltyUpdated(address,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ClaimedTokens"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "EtherReceived"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "FundsWithdrawn"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "LazyMintedTokens"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewClaimConditions"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewOwner"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "NewPrimarySaleRecipient"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "PlatformFeeUpdates"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoyaltyRecipient"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoyaltyUpdated"): EventFragment;
}
declare type ClaimedTokensEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    string,
    string,
    BigNumber
], {
    claimConditionIndex: BigNumber;
    tokenId: BigNumber;
    claimer: string;
    receiver: string;
    quantityClaimed: BigNumber;
}>;
declare type ClaimedTokensEventFilter = TypedEventFilter<ClaimedTokensEvent>;
declare type EtherReceivedEvent = TypedEvent<[
    string,
    BigNumber
], {
    sender: string;
    amount: BigNumber;
}>;
declare type EtherReceivedEventFilter = TypedEventFilter<EtherReceivedEvent>;
declare type FundsWithdrawnEvent = TypedEvent<[
    string,
    string,
    BigNumber,
    BigNumber
], {
    paymentReceiver: string;
    feeRecipient: string;
    totalAmount: BigNumber;
    feeCollected: BigNumber;
}>;
declare type FundsWithdrawnEventFilter = TypedEventFilter<FundsWithdrawnEvent>;
declare type LazyMintedTokensEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    string
], {
    startTokenId: BigNumber;
    endTokenId: BigNumber;
    baseURI: string;
}>;
declare type LazyMintedTokensEventFilter = TypedEventFilter<LazyMintedTokensEvent>;
declare type NewClaimConditionsEvent = TypedEvent<[
    BigNumber,
    IDropERC1155.ClaimConditionStructOutput[]
], {
    tokenId: BigNumber;
    claimConditions: IDropERC1155.ClaimConditionStructOutput[];
}>;
declare type NewClaimConditionsEventFilter = TypedEventFilter<NewClaimConditionsEvent>;
declare type NewOwnerEvent = TypedEvent<[
    string,
    string
], {
    prevOwner: string;
    newOwner: string;
}>;
declare type NewOwnerEventFilter = TypedEventFilter<NewOwnerEvent>;
declare type NewPrimarySaleRecipientEvent = TypedEvent<[
    string
], {
    recipient: string;
}>;
declare type NewPrimarySaleRecipientEventFilter = TypedEventFilter<NewPrimarySaleRecipientEvent>;
declare type PlatformFeeUpdatesEvent = TypedEvent<[
    string,
    BigNumber
], {
    platformFeeRecipient: string;
    platformFeeBps: BigNumber;
}>;
declare type PlatformFeeUpdatesEventFilter = TypedEventFilter<PlatformFeeUpdatesEvent>;
declare type RoyaltyRecipientEvent = TypedEvent<[
    BigNumber,
    string
], {
    tokenId: BigNumber;
    royaltyRecipient: string;
}>;
declare type RoyaltyRecipientEventFilter = TypedEventFilter<RoyaltyRecipientEvent>;
declare type RoyaltyUpdatedEvent = TypedEvent<[
    string,
    BigNumber
], {
    newRoyaltyRecipient: string;
    newRoyaltyBps: BigNumber;
}>;
declare type RoyaltyUpdatedEventFilter = TypedEventFilter<RoyaltyUpdatedEvent>;
declare namespace IDropERC1155 {
    type ClaimConditionStruct = {
        startTimestamp: BigNumberish;
        maxClaimableSupply: BigNumberish;
        supplyClaimed: BigNumberish;
        quantityLimitPerTransaction: BigNumberish;
        waitTimeInSecondsBetweenClaims: BigNumberish;
        merkleRoot: BytesLike;
        pricePerToken: BigNumberish;
        currency: string;
    };
    type ClaimConditionStructOutput = [
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber,
        string,
        BigNumber,
        string
    ] & {
        startTimestamp: BigNumber;
        maxClaimableSupply: BigNumber;
        supplyClaimed: BigNumber;
        quantityLimitPerTransaction: BigNumber;
        waitTimeInSecondsBetweenClaims: BigNumber;
        merkleRoot: string;
        pricePerToken: BigNumber;
        currency: string;
    };
}
interface IDropERC1155 extends BaseContract {
    contractName: string | "IDropERC1155";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IDropERC1155Interface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        claim(_receiver: string, _tokenId: BigNumberish, _quantity: BigNumberish, _proofs: BytesLike[], overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        contractType(overrides?: CallOverrides): Promise<[string]>;
        contractURI(overrides?: CallOverrides): Promise<[string]>;
        contractVersion(overrides?: CallOverrides): Promise<[number]>;
        getPlatformFeeInfo(overrides?: CallOverrides): Promise<[
            string,
            number
        ] & {
            platformFeeRecipient: string;
            platformFeeBps: number;
        }>;
        getRoyaltyInfo(overrides?: CallOverrides): Promise<[string, number]>;
        getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        lazyMint(_amount: BigNumberish, _baseURIForTokens: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        primarySaleRecipient(overrides?: CallOverrides): Promise<[string]>;
        royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            BigNumber
        ] & {
            receiver: string;
            royaltyAmount: BigNumber;
        }>;
        setClaimConditions(_tokenId: BigNumberish, _conditions: IDropERC1155.ClaimConditionStruct[], _resetRestriction: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setContractURI(_uri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setOwner(_newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPrimarySaleRecipient(_saleRecipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<[boolean]>;
    };
    claim(_receiver: string, _tokenId: BigNumberish, _quantity: BigNumberish, _proofs: BytesLike[], overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    contractType(overrides?: CallOverrides): Promise<string>;
    contractURI(overrides?: CallOverrides): Promise<string>;
    contractVersion(overrides?: CallOverrides): Promise<number>;
    getPlatformFeeInfo(overrides?: CallOverrides): Promise<[
        string,
        number
    ] & {
        platformFeeRecipient: string;
        platformFeeBps: number;
    }>;
    getRoyaltyInfo(overrides?: CallOverrides): Promise<[string, number]>;
    getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
    lazyMint(_amount: BigNumberish, _baseURIForTokens: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    owner(overrides?: CallOverrides): Promise<string>;
    primarySaleRecipient(overrides?: CallOverrides): Promise<string>;
    royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<[
        string,
        BigNumber
    ] & {
        receiver: string;
        royaltyAmount: BigNumber;
    }>;
    setClaimConditions(_tokenId: BigNumberish, _conditions: IDropERC1155.ClaimConditionStruct[], _resetRestriction: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setContractURI(_uri: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setOwner(_newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPrimarySaleRecipient(_saleRecipient: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
    callStatic: {
        claim(_receiver: string, _tokenId: BigNumberish, _quantity: BigNumberish, _proofs: BytesLike[], overrides?: CallOverrides): Promise<void>;
        contractType(overrides?: CallOverrides): Promise<string>;
        contractURI(overrides?: CallOverrides): Promise<string>;
        contractVersion(overrides?: CallOverrides): Promise<number>;
        getPlatformFeeInfo(overrides?: CallOverrides): Promise<[
            string,
            number
        ] & {
            platformFeeRecipient: string;
            platformFeeBps: number;
        }>;
        getRoyaltyInfo(overrides?: CallOverrides): Promise<[string, number]>;
        getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
        lazyMint(_amount: BigNumberish, _baseURIForTokens: string, overrides?: CallOverrides): Promise<void>;
        owner(overrides?: CallOverrides): Promise<string>;
        primarySaleRecipient(overrides?: CallOverrides): Promise<string>;
        royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            BigNumber
        ] & {
            receiver: string;
            royaltyAmount: BigNumber;
        }>;
        setClaimConditions(_tokenId: BigNumberish, _conditions: IDropERC1155.ClaimConditionStruct[], _resetRestriction: boolean, overrides?: CallOverrides): Promise<void>;
        setContractURI(_uri: string, overrides?: CallOverrides): Promise<void>;
        setOwner(_newOwner: string, overrides?: CallOverrides): Promise<void>;
        setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setPrimarySaleRecipient(_saleRecipient: string, overrides?: CallOverrides): Promise<void>;
        setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: CallOverrides): Promise<void>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
    };
    filters: {
        "ClaimedTokens(uint256,uint256,address,address,uint256)"(claimConditionIndex?: BigNumberish | null, tokenId?: BigNumberish | null, claimer?: string | null, receiver?: null, quantityClaimed?: null): ClaimedTokensEventFilter;
        ClaimedTokens(claimConditionIndex?: BigNumberish | null, tokenId?: BigNumberish | null, claimer?: string | null, receiver?: null, quantityClaimed?: null): ClaimedTokensEventFilter;
        "EtherReceived(address,uint256)"(sender?: null, amount?: null): EtherReceivedEventFilter;
        EtherReceived(sender?: null, amount?: null): EtherReceivedEventFilter;
        "FundsWithdrawn(address,address,uint256,uint256)"(paymentReceiver?: string | null, feeRecipient?: null, totalAmount?: null, feeCollected?: null): FundsWithdrawnEventFilter;
        FundsWithdrawn(paymentReceiver?: string | null, feeRecipient?: null, totalAmount?: null, feeCollected?: null): FundsWithdrawnEventFilter;
        "LazyMintedTokens(uint256,uint256,string)"(startTokenId?: null, endTokenId?: null, baseURI?: null): LazyMintedTokensEventFilter;
        LazyMintedTokens(startTokenId?: null, endTokenId?: null, baseURI?: null): LazyMintedTokensEventFilter;
        "NewClaimConditions(uint256,tuple[])"(tokenId?: BigNumberish | null, claimConditions?: null): NewClaimConditionsEventFilter;
        NewClaimConditions(tokenId?: BigNumberish | null, claimConditions?: null): NewClaimConditionsEventFilter;
        "NewOwner(address,address)"(prevOwner?: null, newOwner?: null): NewOwnerEventFilter;
        NewOwner(prevOwner?: null, newOwner?: null): NewOwnerEventFilter;
        "NewPrimarySaleRecipient(address)"(recipient?: string | null): NewPrimarySaleRecipientEventFilter;
        NewPrimarySaleRecipient(recipient?: string | null): NewPrimarySaleRecipientEventFilter;
        "PlatformFeeUpdates(address,uint256)"(platformFeeRecipient?: null, platformFeeBps?: null): PlatformFeeUpdatesEventFilter;
        PlatformFeeUpdates(platformFeeRecipient?: null, platformFeeBps?: null): PlatformFeeUpdatesEventFilter;
        "RoyaltyRecipient(uint256,address)"(tokenId?: BigNumberish | null, royaltyRecipient?: null): RoyaltyRecipientEventFilter;
        RoyaltyRecipient(tokenId?: BigNumberish | null, royaltyRecipient?: null): RoyaltyRecipientEventFilter;
        "RoyaltyUpdated(address,uint256)"(newRoyaltyRecipient?: null, newRoyaltyBps?: null): RoyaltyUpdatedEventFilter;
        RoyaltyUpdated(newRoyaltyRecipient?: null, newRoyaltyBps?: null): RoyaltyUpdatedEventFilter;
    };
    estimateGas: {
        claim(_receiver: string, _tokenId: BigNumberish, _quantity: BigNumberish, _proofs: BytesLike[], overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        contractType(overrides?: CallOverrides): Promise<BigNumber>;
        contractURI(overrides?: CallOverrides): Promise<BigNumber>;
        contractVersion(overrides?: CallOverrides): Promise<BigNumber>;
        getPlatformFeeInfo(overrides?: CallOverrides): Promise<BigNumber>;
        getRoyaltyInfo(overrides?: CallOverrides): Promise<BigNumber>;
        getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        lazyMint(_amount: BigNumberish, _baseURIForTokens: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        primarySaleRecipient(overrides?: CallOverrides): Promise<BigNumber>;
        royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        setClaimConditions(_tokenId: BigNumberish, _conditions: IDropERC1155.ClaimConditionStruct[], _resetRestriction: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setContractURI(_uri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setOwner(_newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPrimarySaleRecipient(_saleRecipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        claim(_receiver: string, _tokenId: BigNumberish, _quantity: BigNumberish, _proofs: BytesLike[], overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        contractType(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        contractURI(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        contractVersion(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPlatformFeeInfo(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoyaltyInfo(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        lazyMint(_amount: BigNumberish, _baseURIForTokens: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        primarySaleRecipient(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setClaimConditions(_tokenId: BigNumberish, _conditions: IDropERC1155.ClaimConditionStruct[], _resetRestriction: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setContractURI(_uri: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setOwner(_newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPlatformFeeInfo(_platformFeeRecipient: string, _platformFeeBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPrimarySaleRecipient(_saleRecipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}

export { ClaimedTokensEvent, ClaimedTokensEventFilter, EtherReceivedEvent, EtherReceivedEventFilter, FundsWithdrawnEvent, FundsWithdrawnEventFilter, IDropERC1155, IDropERC1155Interface, LazyMintedTokensEvent, LazyMintedTokensEventFilter, NewClaimConditionsEvent, NewClaimConditionsEventFilter, NewOwnerEvent, NewOwnerEventFilter, NewPrimarySaleRecipientEvent, NewPrimarySaleRecipientEventFilter, PlatformFeeUpdatesEvent, PlatformFeeUpdatesEventFilter, RoyaltyRecipientEvent, RoyaltyRecipientEventFilter, RoyaltyUpdatedEvent, RoyaltyUpdatedEventFilter };
