import { utils, BigNumberish, BytesLike, BigNumber, BaseContract, Signer, CallOverrides, Overrides, ContractTransaction, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result, EventFragment } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common';

interface IThirdwebRoyaltyInterface extends utils.Interface {
    contractName: string | "IThirdwebRoyalty";
    functions: {
        "getRoyaltyInfo()": FunctionFragment;
        "getRoyaltyRecipientForToken(uint256)": FunctionFragment;
        "royaltyInfo(uint256,uint256)": FunctionFragment;
        "setRoyaltyInfo(address,uint256)": FunctionFragment;
        "setRoyaltyRecipientForToken(uint256,address)": FunctionFragment;
        "supportsInterface(bytes4)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "getRoyaltyInfo", values?: undefined): string;
    encodeFunctionData(functionFragment: "getRoyaltyRecipientForToken", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "royaltyInfo", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setRoyaltyInfo", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setRoyaltyRecipientForToken", values: [BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "supportsInterface", values: [BytesLike]): string;
    decodeFunctionResult(functionFragment: "getRoyaltyInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoyaltyRecipientForToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "royaltyInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRoyaltyInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRoyaltyRecipientForToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supportsInterface", data: BytesLike): Result;
    events: {
        "RoyaltyRecipient(uint256,address)": EventFragment;
        "RoyaltyUpdated(address,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "RoyaltyRecipient"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoyaltyUpdated"): EventFragment;
}
declare type RoyaltyRecipientEvent = TypedEvent<[
    BigNumber,
    string
], {
    tokenId: BigNumber;
    royaltyRecipient: string;
}>;
declare type RoyaltyRecipientEventFilter = TypedEventFilter<RoyaltyRecipientEvent>;
declare type RoyaltyUpdatedEvent = TypedEvent<[
    string,
    BigNumber
], {
    newRoyaltyRecipient: string;
    newRoyaltyBps: BigNumber;
}>;
declare type RoyaltyUpdatedEventFilter = TypedEventFilter<RoyaltyUpdatedEvent>;
interface IThirdwebRoyalty extends BaseContract {
    contractName: string | "IThirdwebRoyalty";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IThirdwebRoyaltyInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        getRoyaltyInfo(overrides?: CallOverrides): Promise<[string, number]>;
        getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            BigNumber
        ] & {
            receiver: string;
            royaltyAmount: BigNumber;
        }>;
        setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<[boolean]>;
    };
    getRoyaltyInfo(overrides?: CallOverrides): Promise<[string, number]>;
    getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
    royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<[
        string,
        BigNumber
    ] & {
        receiver: string;
        royaltyAmount: BigNumber;
    }>;
    setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
    callStatic: {
        getRoyaltyInfo(overrides?: CallOverrides): Promise<[string, number]>;
        getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<string>;
        royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            BigNumber
        ] & {
            receiver: string;
            royaltyAmount: BigNumber;
        }>;
        setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: CallOverrides): Promise<void>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
    };
    filters: {
        "RoyaltyRecipient(uint256,address)"(tokenId?: BigNumberish | null, royaltyRecipient?: null): RoyaltyRecipientEventFilter;
        RoyaltyRecipient(tokenId?: BigNumberish | null, royaltyRecipient?: null): RoyaltyRecipientEventFilter;
        "RoyaltyUpdated(address,uint256)"(newRoyaltyRecipient?: null, newRoyaltyBps?: null): RoyaltyUpdatedEventFilter;
        RoyaltyUpdated(newRoyaltyRecipient?: null, newRoyaltyBps?: null): RoyaltyUpdatedEventFilter;
    };
    estimateGas: {
        getRoyaltyInfo(overrides?: CallOverrides): Promise<BigNumber>;
        getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        getRoyaltyInfo(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoyaltyRecipientForToken(tokenId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        royaltyInfo(tokenId: BigNumberish, salePrice: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setRoyaltyInfo(_royaltyRecipient: string, _royaltyBps: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setRoyaltyRecipientForToken(tokenId: BigNumberish, recipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}

export { IThirdwebRoyalty, IThirdwebRoyaltyInterface, RoyaltyRecipientEvent, RoyaltyRecipientEventFilter, RoyaltyUpdatedEvent, RoyaltyUpdatedEventFilter };
